@@ -39,7 +39,7 @@ class HeSetupWizardContainer extends Component {
         this.virtSupported = this.defaultsProvider.virtSupported();
         this.sufficientMemAvail = this.defaultsProvider.sufficientMemAvail();
 
-        const loadingSuccessful = this.systemDataRetrieved && this.libvirtRunning &&this.virtSupported && this.sufficientMemAvail;
+        const loadingSuccessful = this.systemDataRetrieved && this.libvirtRunning && this.virtSupported && this.sufficientMemAvail;
         const loadingStatus = loadingSuccessful ? status.SUCCESS : status.FAILURE;
 
         let systemData = null;
@@ -75,6 +75,8 @@ class HeSetupWizardContainer extends Component {
             const glusterAnsFile = gdeployAnsFiles[0];
             const setupModel = this.state.heSetupModel.model;
             this.state.heSetupModel.addGlusterValues(glusterAnsFile, setupModel);
+            setupModel.storage.domainType.value = "glusterfs";
+            this.setState({ setupModel });
         } else {
             console.log(messages.NO_GDEPLOY_ANSWER_FILES_FOUND);
         }
