@@ -131,6 +131,7 @@ export class HeSetupModel {
                     value: "nfs",
                     type: types.STRING,
                     showInReview: true,
+                    reviewOrder: 0,
                     uiStage: "Storage",
                     useInAnswerFile: true,
                     required: false
@@ -140,9 +141,10 @@ export class HeSetupModel {
                     ansibleVarName: "NFS_VERSION",
                     ansiblePhasesUsed: [phases.CREATE_STORAGE, phases.TARGET_VM],
                     description: "NFS Version",
-                    value: "3",
+                    value: "auto",
                     type: types.STRING,
                     showInReview: true,
+                    reviewOrder: 5,
                     uiStage: "Storage",
                     useInAnswerFile: false,
                     required: false
@@ -151,14 +153,15 @@ export class HeSetupModel {
                     name: "imgSizeGB",
                     ansibleVarName: "DISK_SIZE",
                     ansiblePhasesUsed: [phases.TARGET_VM],
-                    description: "Disk Size (GB)",
+                    description: "Disk Size (GiB)",
                     value: resourceConstants.VM_DISK_MIN_GB,
                     type: types.STRING,
                     showInReview: true,
-                    uiStage: "VM",
+                    reviewOrder: 100,
+                    uiStage: "Storage",
                     useInAnswerFile: true,
                     required: true,
-                    range: {min: resourceConstants.VM_DISK_MIN_GB, max: 4096}
+                    range: {min: resourceConstants.VM_DISK_MIN_GB, max: resourceConstants.VM_DISK_MAX_GB}
                 },
                 storagePath: {
                     name: "storagePath",
@@ -180,6 +183,7 @@ export class HeSetupModel {
                     value: "hosted_storage",
                     type: types.STRING,
                     showInReview: true,
+                    reviewOrder: 110,
                     uiStage: "Storage",
                     useInAnswerFile: true,
                     required: true
@@ -204,6 +208,7 @@ export class HeSetupModel {
                     value: "",
                     type: types.STRING,
                     showInReview: false,
+                    reviewOrder: 10,
                     uiStage: "Storage",
                     useInAnswerFile: false,
                     required: true
@@ -216,6 +221,7 @@ export class HeSetupModel {
                     value: "",
                     type: types.STRING,
                     showInReview: false,
+                    reviewOrder: 10,
                     uiStage: "Storage",
                     useInAnswerFile: false,
                     required: false
@@ -228,6 +234,7 @@ export class HeSetupModel {
                     value: "",
                     type: types.STRING,
                     showInReview: true,
+                    reviewOrder: 20,
                     uiStage: "Storage",
                     useInAnswerFile: true,
                     required: false
@@ -353,23 +360,27 @@ export class HeSetupModel {
             network: {
                 bridgeIf: {
                     name: "bridgeIf",
+                    ansibleVarName: "BRIDGE_IF",
+                    ansiblePhasesUsed: [phases.BOOTSTRAP_VM],
                     description: "Bridge Interface",
                     value: "",
                     type: types.STRING,
                     showInReview: true,
-                    uiStage: "Network",
+                    reviewOrder: 60,
+                    uiStage: "VM",
                     useInAnswerFile: true,
                     required: false
                 },
                 bridgeName: {
                     name: "bridgeName",
                     ansibleVarName: "BRIDGE",
-                    ansiblePhasesUsed: [phases.TARGET_VM],
+                    ansiblePhasesUsed: [phases.BOOTSTRAP_VM, phases.TARGET_VM],
                     description: "Bridge Name",
                     value: "ovirtmgmt",
                     type: types.STRING,
                     showInReview: true,
-                    uiStage: "Network",
+                    reviewOrder: 130,
+                    uiStage: "VM",
                     useInAnswerFile: true,
                     required: true
                 },
@@ -391,7 +402,8 @@ export class HeSetupModel {
                     value: "",
                     type: types.STRING,
                     showInReview: true,
-                    uiStage: "Network",
+                    reviewOrder: 40,
+                    uiStage: "VM",
                     useInAnswerFile: true,
                     required: true,
                     regex: Validation.ipAddress,
@@ -405,12 +417,14 @@ export class HeSetupModel {
                         phases.BOOTSTRAP_VM,
                         phases.CREATE_STORAGE,
                         phases.TARGET_VM,
-                        phases.ISCSI_DISCOVER
+                        phases.ISCSI_DISCOVER,
+                        phases.ISCSI_GET_DEVICES
                     ],
                     description: "Engine FQDN",
                     value: "",
                     type: types.STRING,
                     showInReview: true,
+                    reviewOrder: 0,
                     uiStage: "VM",
                     useInAnswerFile: true,
                     required: true
@@ -419,10 +433,11 @@ export class HeSetupModel {
                     name: "host_name",
                     ansibleVarName: "HOST_ADDRESS",
                     ansiblePhasesUsed: [phases.BOOTSTRAP_VM, phases.TARGET_VM],
-                    description: "Host IP or FQDN",
+                    description: "Host FQDN",
                     value: "",
                     type: types.STRING,
                     showInReview: false,
+                    reviewOrder: 140,
                     uiStage: "VM",
                     useInAnswerFile: false,
                     required: false
@@ -447,6 +462,7 @@ export class HeSetupModel {
                     value: "1",
                     type: types.STRING,
                     showInReview: true,
+                    reviewOrder: 90,
                     uiStage: "VM",
                     useInAnswerFile: true,
                     required: true,
@@ -508,6 +524,7 @@ export class HeSetupModel {
                     value: "00:16:3E:6A:7A:F9",
                     type: types.STRING,
                     showInReview: true,
+                    reviewOrder: 10,
                     uiStage: "VM",
                     useInAnswerFile: true,
                     required: false,
@@ -521,7 +538,7 @@ export class HeSetupModel {
                     description: "VM IP Prefix",
                     value: "",
                     type: types.STRING,
-                    showInReview: true,
+                    showInReview: false,
                     uiStage: "VM",
                     useInAnswerFile: false,
                     required: false
@@ -530,15 +547,16 @@ export class HeSetupModel {
                     name: "vmMemSizeMB",
                     ansibleVarName: "MEM_SIZE",
                     ansiblePhasesUsed: [phases.BOOTSTRAP_VM, phases.TARGET_VM],
-                    description: "Memory Size (MB)",
-                    value: "16384",
+                    description: "Memory Size (MiB)",
+                    value: resourceConstants.VM_MEM_MIN_RECOMMENDED_MB,
                     unit: "MB",
                     type: types.INTEGER,
                     showInReview: true,
+                    reviewOrder: 100,
                     uiStage: "VM",
                     useInAnswerFile: true,
                     required: true,
-                    range: {min: resourceConstants.VM_MEM_MIN_MB, max: 16384}
+                    range: {min: resourceConstants.VM_MEM_MIN_MB, max: resourceConstants.VM_MEM_MIN_RECOMMENDED_MB}
                 },
                 networkConfigType: {
                     name: "networkConfigType",
@@ -546,6 +564,7 @@ export class HeSetupModel {
                     value: "dhcp",
                     type: types.STRING,
                     showInReview: true,
+                    reviewOrder: 20,
                     uiStage: "VM",
                     useInAnswerFile: false,
                     required: false
@@ -553,17 +572,28 @@ export class HeSetupModel {
                 cloudinitVMStaticCIDR: {
                     name: "cloudinitVMStaticCIDR",
                     ansibleVarName: "VM_IP_ADDR",
-                    ansiblePhasesUsed: [phases.TARGET_VM],
-                    description: "IP Address",
+                    ansiblePhasesUsed: [phases.BOOTSTRAP_VM, phases.TARGET_VM],
+                    description: "VM IP Address",
                     value: "",
                     type: types.STRING,
                     showInReview: false,
+                    reviewOrder: 30,
                     uiStage: "VM",
                     useInAnswerFile: true,
                     required: false,
                     regex: Validation.ipAddress,
                     errorMsg: "Invalid format for IP address"
                 },
+                cloudinitVMStaticCIDRPrefix: {
+                    name: "cloudinitVMStaticCIDRPrefix",
+                    description: "IP Address Prefix",
+                    value: "",
+                    type: types.STRING,
+                    showInReview: false,
+                    uiStage: "VM",
+                    useInAnswerFile: false,
+                    required: false
+                },
                 cloudinitVMDNS: {
                     name: "cloudinitVMDNS",
                     ansibleVarName: "DNS_ADDR",
@@ -572,6 +602,7 @@ export class HeSetupModel {
                     value: [""],
                     type: types.STRING,
                     showInReview: false,
+                    reviewOrder: 50,
                     uiStage: "VM",
                     useInAnswerFile: true,
                     required: false
@@ -593,7 +624,7 @@ export class HeSetupModel {
                     description: "Host Time Zone",
                     value: "America/New_York",
                     type: types.STRING,
-                    showInReview: true,
+                    showInReview: false,
                     uiStage: "VM",
                     useInAnswerFile: true,
                     required: false
@@ -627,7 +658,7 @@ export class HeSetupModel {
                     description: "Engine VM Host Name",
                     value: "ovirt-engine",
                     type: types.STRING,
-                    showInReview: true,
+                    showInReview: false,
                     uiStage: "VM",
                     useInAnswerFile: true,
                     required: false
@@ -639,7 +670,7 @@ export class HeSetupModel {
                     description: "Engine VM Domain",
                     value: "localdomain",
                     type: types.STRING,
-                    showInReview: true,
+                    showInReview: false,
                     uiStage: "VM",
                     useInAnswerFile: true,
                     required: false
@@ -672,6 +703,7 @@ export class HeSetupModel {
                     value: "",
                     type: types.STRING,
                     showInReview: false,
+                    reviewOrder: 70,
                     uiStage: "VM",
                     useInAnswerFile: false,
                     required: false
@@ -694,6 +726,7 @@ export class HeSetupModel {
                     value: "",
                     type: types.STRING,
                     showInReview: true,
+                    reviewOrder: 110,
                     uiStage: "VM",
                     useInAnswerFile: true,
                     required: false
@@ -706,6 +739,7 @@ export class HeSetupModel {
                     value: "yes",
                     type: types.STRING,
                     showInReview: true,
+                    reviewOrder: 80,
                     uiStage: "VM",
                     useInAnswerFile: true,
                     required: false
@@ -718,6 +752,7 @@ export class HeSetupModel {
                     value: true,
                     type: types.BOOLEAN,
                     showInReview: true,
+                    reviewOrder: 120,
                     uiStage: "VM",
                     useInAnswerFile: true,
                     required: false
@@ -847,12 +882,14 @@ export class HeSetupModel {
                         phases.BOOTSTRAP_VM,
                         phases.CREATE_STORAGE,
                         phases.TARGET_VM,
-                        phases.ISCSI_DISCOVER
+                        phases.ISCSI_DISCOVER,
+                        phases.ISCSI_GET_DEVICES
                     ],
                     description: "Admin Portal Password",
                     value: "",
                     type: types.STRING,
                     showInReview: false,
+                    reviewOrder: 0,
                     uiStage: "Engine",
                     useInAnswerFile: false,
                     required: false
@@ -886,7 +923,8 @@ export class HeSetupModel {
                         phases.BOOTSTRAP_VM,
                         phases.CREATE_STORAGE,
                         phases.TARGET_VM,
-                        phases.ISCSI_DISCOVER
+                        phases.ISCSI_DISCOVER,
+                        phases.ISCSI_GET_DEVICES
                     ],
                     description: "Host's name",
                     value: "",
@@ -905,7 +943,7 @@ export class HeSetupModel {
                     description: "Console Type",
                     value: "vnc",
                     type: types.STRING,
-                    showInReview: true,
+                    showInReview: false,
                     uiStage: "VM",
                     useInAnswerFile: true,
                     required: false
@@ -917,7 +955,7 @@ export class HeSetupModel {
                     description: "CPU Type",
                     value: "Conroe",
                     type: types.STRING,
-                    showInReview: true,
+                    showInReview: false,
                     uiStage: "VM",
                     useInAnswerFile: true,
                     required: false
@@ -958,10 +996,11 @@ export class HeSetupModel {
                     name: "smtpServer",
                     ansibleVarName: "SMTP_SERVER",
                     ansiblePhasesUsed: [phases.TARGET_VM],
-                    description: "Notifications SMTP Server",
+                    description: "SMTP Server Name",
                     value: "localhost",
                     type: types.STRING,
                     showInReview: true,
+                    reviewOrder: 10,
                     uiStage: "Engine",
                     useInAnswerFile: true,
                     required: false
@@ -970,10 +1009,11 @@ export class HeSetupModel {
                     name: "smtpPort",
                     ansibleVarName: "SMTP_PORT",
                     ansiblePhasesUsed: [phases.TARGET_VM],
-                    description: "SMTP Port Number",
+                    description: "SMTP Server Port Number",
                     value: "25",
                     type: types.STRING,
                     showInReview: true,
+                    reviewOrder: 20,
                     uiStage: "Engine",
                     useInAnswerFile: true,
                     required: false,
@@ -984,10 +1024,11 @@ export class HeSetupModel {
                     name: "sourceEmail",
                     ansibleVarName: "SOURCE_EMAIL",
                     ansiblePhasesUsed: [phases.TARGET_VM],
-                    description: "SMTP Sender E-Mail Address",
+                    description: "Sender E-Mail Address",
                     value: "root@localhost",
                     type: types.STRING,
                     showInReview: true,
+                    reviewOrder: 30,
                     uiStage: "Engine",
                     useInAnswerFile: true,
                     required: false
@@ -996,10 +1037,11 @@ export class HeSetupModel {
                     name: "destEmail",
                     ansibleVarName: "DEST_EMAIL",
                     ansiblePhasesUsed: [phases.TARGET_VM],
-                    description: "SMTP Recipient E-Mail Addresses",
+                    description: "Recipient E-Mail Addresses",
                     value: ["root@localhost"],
                     type: types.STRING,
                     showInReview: true,
+                    reviewOrder: 40,
                     uiStage: "Engine",
                     useInAnswerFile: true,
                     required: false
